==> librenms-1.43p0v0.tgz: librenms/AUTHORS.md <==
LibreNMS core team:
- Paul Gear <paul@librenms.org> [paulgear](https://github.com/paulgear/)
- Neil Lathwood <neil@librenms.org> [laf](https://github.com/laf/)
- Daniel Preussker <f0o@librenms.org> [f0o](https://github.com/f0o/)
- Søren Friis Rosiak <sorenrosiak@gmail.com> [rosiak](https://github.com/rosiak/)
- Mike Rostermund <mike@kollegienet.dk> [SaaldjorMike](https://github.com/SaaldjorMike/)
- Tony Murray <tonym@librenms.org> [murrant](https://github.com/murrant/)
- David Bell <me@geordish.org> [geordish](https://github.com/geordish/)

Notable contributors:
- Cercel Valentin <crc@nuamchefazi.ro> (crcro)
- Clint Armstrong <clint@clintarmstrong.net> (clinta)
- Aaron Daniels <aaron@daniels.id.au> (adaniels21487)

LibreNMS contributors:
- Bohdan Sanders <git@bohdans.com> (bohdan-s)
- Toni Cunyat <elbuit@gmail.com> (elbuit)
- Tuomas Riihimäki <tuomari@iudex.fi> (tuomari)
- Nicolas Armando <nicearma@yahoo.com> (nicearma)
- Micah Chasteen <mjchasteen@gmail.com> (mchasteen)
- Kevin Fleshman <fleshmank@hotmail.com> (KFleshman)
- Markus Heberling <markus@tisoft.de> (tisoft)
- Alan Gregory <alan@opcaonet.com.br> (alangregory)
- Joubert RedRat <me+github@redrat.com.br> (joubertredrat)
- Len Lin <Ultra2D@users.noreply.github.com> (Ultra2D)
- Christopher Freas <code@packetbusters.net> (nwautomator)
- Stuart Henderson <stu@spacehopper.org> (sthen)
- Filippo Giunchedi <filippo@esaurito.net> (filippog)
- Lasse Leegaard <lasse@brandbil.dk> (lasseleegaard)
- Mickael Marchand  <mmarchand@corp.free.fr> (mmarchand)
- Mohammad Al-Shami <mohammad@al-shami.net> (mohshami)
- Rudy Hardeman <zarya@gigafreak.net> (zarya)
- Freddie Cash <fjwcash@gmail.com> (fjwcash)
- Thom Seddon <thom@seddonmedia.co.uk> (thomseddon)
- Vitali Kari <vitali.kari@gmail.com> (vitalisator)
- James Campbell <neokjames@gmail.com> (neokjames)
- Steve Calvário <calvario.steve@gmail.com> (Calvario)
- Christian Marg <marg@rz.tu-clausthal.de> (einhirn)
- Louis Rossouw <lrossouw@gmail.com> (spinza)
- Tony Ditchfield  <tony.ditchfield@gmail.com> (arnoldthebat)
- Travis Hegner <travis.hegner@gmail.com> (travishegner)
- Will Jones <email@willjones.eu> (willjones)
- Job Snijders <job@instituut.net> (job)
- Rasmus Aberg <rasmus@sthix.net> (rasssta)
- Jan Saner <jan@trick77.com> (trick77)
- Mikhail Bratchikov <mbratchikov@odin.com> (pepyaka)
- David M. Syzdek <david@syzdek.net> (syzdek)
- Gerben Meijer <gerben@daybyday.nl> (infernix)
- Michael Newton <mnewton@pofp.com> (miken32)
- Tom Ferguson <tom.ferguson.public@outlook.com> (Tawmu)
- Jimmy Cleuren <jimmy.cleuren@gmail.com> (jimmycleuren)
- Mark Schouten <mark@tuxis.nl> (tuxis-ie)
- Todd Eddy <vr@vrillusions.com> (vrillusions)
- Arjit Chaudhary <arjit.c@gmail.com> (arjitc)
- Sergiusz Paprzycki <serek@walcz.net> (spaprzycki)
- Juho Vanhanen <juho@vanhanen.me> (juhovan)
- Bart de Bruijn <bart_de_bruijn@yahoo.com> (bartdebruijn)
- Christophe Martinet <martinet.christophe@gmail.com> (chrisgfx)
- Nils Steinger <librenms@voidptr.de> (n-st)
- Mark Nagel <mnagel@willingminds.com> (ciscoqid)
- Sławomir Paszkiewicz <paszczus@pld-linux.org> (paszczus)
- Frederik Mogensen <frederik@server-1.dk> (mogensen)
- Matthew Scully <matt@mattz0r.me.uk> (mattz0r)
- Xavier Beaudouin <kiwi@oav.net> (xbeaudouin)
- Falk Stern <falk@fourecks.de> (fstern)
- Donovan Bridoux <donovan.bridoux@gmail.com> (PandaWawawa)
- Sebastian Neuner <sebastian@sneuner.org> (9er)
- Robert Zollner <wolfit_ro@yahoo.com> (Lupul)
- Richard Hartmann <richih@debian.org> (RichiH)
- Robert Gornall <roblnm@khobbits.co.uk> (KHobbits)
- Rob Gormley <robert@gormley.me> (rgormley)
- Richard Kojedzinszky <krichy@nmdps.net> (rkojedzinszky)
- Peter Lamperud <peter.lamperud@gmail.com> (vizay)
- Louis Bailleul <louis.bailleul@gmail.com> (alucardfh)
- Rick Hodger <rick@fuzzi.org.uk> (Tatermen)
- Eldon Koyle <ekoyle@gmail.com> (ekoyle)
- Jay McEntire <jay.mcentire@gmail.com> (jmacul2)
- Jonathan Bailey <jcbailey@code0.net> (jcbailey2)
- Ruairi Carroll <ruairi.carroll@gmail.com> (rucarrol)
- Maxim Tsyplakov <maxim.tsyplakov@gmail.com> (tsypa)
- D. Britz <github@wrind.de> (flatterlight)
- Tobias Herrmann <tobias@fiveninedigital.ch> (Mightea)
- Nicolas Guillaumin <nicolas+github@guillaumin.me> (nguillaumin)
- Jurrian van Iersel <jurrian@vaniersel.net> (jviersel)
- Adam Winberg <adam.winberg@gmail.com> (wiad)
- Maximilian Wilhelm <max@rfc2324.org> (BarbarossaTM)
- Jameson Finney <jameson.finney@gmail.com> (JamesonFinney)
- John Wells <john.wells@greatworx.com> (jbwiv)
- Henoc Khouilla <henoc.khouilla@gmail.com> (henocKA)
- Paul Blasquez <pblasquez@gmail.com> (pblasquez)
- Paul Heinrichs <pdheinrichs@gmail.com> (pheinrichs)
- Georges Dick <georges.dick@gmail.com> (GeorgesDick)
- Richard Lawley <richard@richardlawley.com> (richardlawley)
- Marco Di Cerbo <marco@dottoremoe.com> (marcodc)
- Ibrahim Tachijian <barhom@netsat.se> (barhom)
- Guillaume Coeugnet <aliasprotect-git@yahoo.fr> (gcoeugnet)
- Jared Newell <jared.newell@gmail.com> (Jaredn)
- Karsten Nerdinger <karsten-git-librenms@nerdinger.net> (piratonym)
- Michael Nguyen <mnguyen1289@gmail.com> (mnguyen1289)
- Casey Schoonover <casey.schoonover@llcc.edu> (cschoonover91)
- Chris A. Evans <thecityofguanyu@outlook.com> (thecityofguanyu)
- Rainer Schüler <github@layer3.de> (rschueler)
- Jussi Sorjonen <mieleton@mieleton.net> (mieleton)
- Jens Langhammer <jens@beryju.org> (BeryJu)
- Robert Verspuy <robert@exa.nl> (exarv)
- Peter Tkatchenko <peter@flytrace.com> (Peter2121)
- Marc Runkel <marc@runkel.org> (mrunkel)
- Josh Driver <keeperofdakeys@gmail.com> (keeperofdakeys)
- Felix Eckhofer <felix@eckhofer.com> (tribut)
- Vikram Adukia <adukia@dropbox.com> (justmedude)
- Tijmen de Mes <tijmen@ag-projects.com> (tijmenNL)
- Benjamin Busche <benjamin.busche@gmail.com> (optic00)
- Brandon Boudrias <bt.boudrias@gmail.com> (brandune)
- Andy Noyland <andrew@noyland.co.uk> (Zappatron)
- Ahmed Sajid <ahmed4343@hotmail.com> (ahmedsajid)
- Karsten Schmidt <git@guggemand.dk> (guggemand)
- Maxence POULAIN <maxence.poulain@eriador.info> (Linutux42)
- Florian Beer <fb@42dev.eu> (florianbeer)
- Vladislav Solovei <vladsol2009@gmail.com> (vladsol)
- Daniel van Dorp <daniel@vandorp.biz> (djvdorp)
- Phil Regnauld <regnauld@x0.dk> (reegnauld)
- Russell Morris <github@rkmorris.us> (arrmo)
- Bennett Blodinger <bennett.blodinger@gmail.com> (benwa)
- Michael Hansen <nerdalertdk@gmail.com> (nerdalertdk)
- Daniel Cox <danielcoxman@gmail.com> (ospfbgp)
- Joseph Cunningham <joey.was@gmail.com> (joeywas)
- Michael Van Delft <librenms@xo.tc> (HybridAU)
- Piotr Jurga <deutor1361@gmail.com> (deutor)
- Jonathon Koyle <jonathon.koyle@gmail.com> (jonathon-k)
- Tamas Szabo <jobs@szatam.com> (szatam)
- Dennis Væversted <dv@zitcom.dk> (dvaeversted)
- Morgan Henreaux <morgan@henreaux.com> (mhenreaux)
- Yves Boudreau <yves.boudreau@bgp.ca> (boudreau)
- Konrad Bechler <konrad@bechler.pl> (kbechler)
- Florent Bruchez <ftbz@me.com> (ftbz)
- Bartosz Radwan <b.radwan@citypartner.pl> (bartoszradwan)
- Kate Gerry <kate@fansubber.com> (kate66)
- Johan Zaxmy <johan@zaxmy.com> (Zaxmy)
- Ryan Gibbons <rtgibbons23@gmail.com> (rtgibbons)
- Layne Breitkreutz <github@thelenon.com> (Gorian)
- Karl Shea <karl@karlshea.com> (karlshea)
- Jason Ellison <infotek@gmail.com> (infotek)
- Justin Settle <jus10@partlycloudy.org> (jquagga)
- Alexander Kratzsch <klump@devrandom.se> (klump)
- Barry O'Donovan barry.odonovan@lightnet.ie (barryodonovan)
- Joseph Eames <j.eames@outlook.com> (j-ems)
- Eric Conroy <eric@conroy.co> (NetworkNub)
- Timothy Willey <developer@timothywilley.net> (twilley)
- Jon Ward	<librenms@yonzb.net> (yon2004)
- Ian Viemeister <github@ian.viemeister.com> (iviemeister)
- Thane Gill <me@thanegill.com> (thanegill)
- Christoffer Stokbæk <christoffers@easyspeedy.com> (stokbaek)
- Markus Wigge <markus@cultcom.de> (cultcom)
- Matthew Wall <llawwehttam@gmail.com> (llawwehttam)
- Andres Rahn <andreser@gmail.com> (Andreser)
- Philippe Mathieu-Daudé <philmd@users.noreply.github.com> (philmd)
- Christoph Zilian <czilian@hotmail.com> (czilian)
- Guillem Mateos <bbguillem@gmail.com> (guillemmateos)
- Joachim Tingvold <joachim@tingvold.com> (jallakim)
- Martin Zatloukal <slezi2@pvfree.net> (erotel)
- Matthew Schwen <mschwen@gmail.com> (mattschwen)
- Joel Cant <joel@linuxmod.co.uk> (NerdBlender
- Aldemir Akpinar <aldemir.akpinar@gmail.com> (aldemira)
- Rob Nichols <rob@ignition360.com> (rdnn)
- Patrick Fruh <info@kaeltis.de> (Kaeltis)
- Julian Kornberger <jk+github@digineo.de> (corny)
- ant Kenworthy <git@manchetermonkey.co.uk> (mcrmonkey)
- Aleksandr Stankevic <aleksandr.stankevic@gmail.com> (sysmonk)
- Richard Mayhew <richard@splash.co.za> (InsaneSplash)
- Jacob <wackychocolatefactory@gmail.com> (wackychocolatefactory)
- Patrick Velder <patrick2+librenms@velder.li> (patrick7)
- Andrew Wippler <andrew.wippler+librenms@gmail.com> (andrewwippler)
- Robert Towster <rnt-github at towster.com> (towster)
- Rocky Luke <rockyluke@offline.net> (rockyluke)
- Tim Jackson <jackson.tim@gmail.com> (jackson-tim)
- Jørn-Stian Lønsetteig <jeg@glemte.no> (gilrim)
- Viktoria Rei Bauer <vbauer@stargazer.at> (ToeiRei)
- Ryan Eno <ryaneno@gmail.com> (VimCommando)
- Matt Peterson <matt@peterson.org> (dorkmatt)
- William George <wrgeorge1983@gmail.com> (wrgeorge1983)
- Valentin Parmeland <naoko.vp@gmail.com> (NK74)
- Michał Margula <michal@margula.pl> (alchemyx)
- Maclin Fuehr-Bush <macfuehrbush@gmail.com> (mobilemaclin)
- Robert Penziol <rpenziol@pdx.edu> (rpenziol)
- Stefan Behte <craig at haquarter.de> (craig)
- Zane C. Bowers-Hadley <vvelox@vvelox.net> (vvelox)
- Valentin Polonuyer <valik.vicious@gmail.com> (ValikVicious)
- Olivier Le Brouster <olb@nebkha.net> (ollb)
- Avery Payne <avery.p.payne@gmail.com> (apayne)
- Ryan Medlyn <ryan.medlyn@gmail.com> (rmedlyn)
- Mark Hughes <m@rkhugh.es> (markehme)
- Mark Abrahams <mark@abrahams.co.nz> (markabrahams)
- Klaas Tammling <klaas@tammling.hamburg> (KlaasT)
- Simon Mott <me@simonmott.co.uk> (tsumaru720)
- Hubert Ladet <mail4git38@gmail.com> (mail4git38)
- Deeps (deepseth)
- Jari Schäfer <jari.schaefer@gmail.com> (jarischaefer)
- Jan-Philipp Litza <janphilipp@litza.de> (jplitza)
- Chris Putnam <chrisputnam@gmail.com> (putnam)
- Jonathan Price <jonathan@jonathanprice.uk> (Pricetx)
- Remy de Boer <remy@slowpoke.nl> (remydb)
- Ben Klang <ben@alkaloid.net> (bklang)
- Tim Stallard <code@timstallard.me.uk> (TimStallard)
- Svenn D'Hert <admin at svennd.be> (svennd)
- Dominik Bay <db@rrbone.net> (eimann)
- Nick Peelman <nick@peelman.us> (peelman)
- Patrick Ryon <patrick@slashdoom.com> (slashdoom)
- Mike Williams <mike@mgww.net> (network-guy)
- Rob J. Epping <librenms@renf.us> (robje)
- Frank Petrilli <frank@petril.li> (frankpetrilli)
- Joel Kociolek <joel@kociolek.org> (lejoko)
- Rémy Jacquin <remy@remyj.fr> (remyj38)

Observium was written by:
- Adam Armstrong
- Tom Laermans
- various others as indicated in the file contents and commit logs

==> librenms-1.50v0.tgz: librenms/AUTHORS.md <==
LibreNMS core team:
- Paul Gear <paul@librenms.org> [paulgear](https://github.com/paulgear/)
- Neil Lathwood <neil@librenms.org> [laf](https://github.com/laf/)
- Daniel Preussker <f0o@librenms.org> [f0o](https://github.com/f0o/)
- Søren Friis Rosiak <sorenrosiak@gmail.com> [rosiak](https://github.com/rosiak/)
- Mike Rostermund <mike@kollegienet.dk> [SaaldjorMike](https://github.com/SaaldjorMike/)
- Tony Murray <tonym@librenms.org> [murrant](https://github.com/murrant/)
- David Bell <me@geordish.org> [geordish](https://github.com/geordish/)

Notable contributors:
- Cercel Valentin <crc@nuamchefazi.ro> (crcro)
- Clint Armstrong <clint@clintarmstrong.net> (clinta)
- Aaron Daniels <aaron@daniels.id.au> (adaniels21487)

LibreNMS contributors:
- Bohdan Sanders <git@bohdans.com> (bohdan-s)
- Toni Cunyat <elbuit@gmail.com> (elbuit)
- Tuomas Riihimäki <tuomari@iudex.fi> (tuomari)
- Nicolas Armando <nicearma@yahoo.com> (nicearma)
- Micah Chasteen <mjchasteen@gmail.com> (mchasteen)
- Kevin Fleshman <fleshmank@hotmail.com> (KFleshman)
- Markus Heberling <markus@tisoft.de> (tisoft)
- Alan Gregory <alan@opcaonet.com.br> (alangregory)
- Joubert RedRat <me+github@redrat.com.br> (joubertredrat)
- Len Lin <Ultra2D@users.noreply.github.com> (Ultra2D)
- Christopher Freas <code@packetbusters.net> (nwautomator)
- Stuart Henderson <stu@spacehopper.org> (sthen)
- Filippo Giunchedi <filippo@esaurito.net> (filippog)
- Lasse Leegaard <lasse@brandbil.dk> (lasseleegaard)
- Mickael Marchand  <mmarchand@corp.free.fr> (mmarchand)
- Mohammad Al-Shami <mohammad@al-shami.net> (mohshami)
- Rudy Hardeman <zarya@gigafreak.net> (zarya)
- Freddie Cash <fjwcash@gmail.com> (fjwcash)
- Thom Seddon <thom@seddonmedia.co.uk> (thomseddon)
- Vitali Kari <vitali.kari@gmail.com> (vitalisator)
- James Campbell <neokjames@gmail.com> (neokjames)
- Steve Calvário <calvario.steve@gmail.com> (Calvario)
- Christian Marg <marg@rz.tu-clausthal.de> (einhirn)
- Louis Rossouw <lrossouw@gmail.com> (spinza)
- Tony Ditchfield  <tony.ditchfield@gmail.com> (arnoldthebat)
- Travis Hegner <travis.hegner@gmail.com> (travishegner)
- Will Jones <email@willjones.eu> (willjones)
- Job Snijders <job@instituut.net> (job)
- Rasmus Aberg <rasmus@sthix.net> (rasssta)
- Jan Saner <jan@trick77.com> (trick77)
- Mikhail Bratchikov <mbratchikov@odin.com> (pepyaka)
- David M. Syzdek <david@syzdek.net> (syzdek)
- Gerben Meijer <gerben@daybyday.nl> (infernix)
- Michael Newton <mnewton@pofp.com> (miken32)
- Tom Ferguson <tom.ferguson.public@outlook.com> (Tawmu)
- Jimmy Cleuren <jimmy.cleuren@gmail.com> (jimmycleuren)
- Mark Schouten <mark@tuxis.nl> (tuxis-ie)
- Todd Eddy <vr@vrillusions.com> (vrillusions)
- Arjit Chaudhary <arjit.c@gmail.com> (arjitc)
- Sergiusz Paprzycki <serek@walcz.net> (spaprzycki)
- Juho Vanhanen <juho@vanhanen.me> (juhovan)
- Bart de Bruijn <bart_de_bruijn@yahoo.com> (bartdebruijn)
- Christophe Martinet <martinet.christophe@gmail.com> (chrisgfx)
- Nils Steinger <librenms@voidptr.de> (n-st)
- Mark Nagel <mnagel@willingminds.com> (ciscoqid)
- Sławomir Paszkiewicz <paszczus@pld-linux.org> (paszczus)
- Frederik Mogensen <frederik@server-1.dk> (mogensen)
- Matthew Scully <matt@mattz0r.me.uk> (mattz0r)
- Xavier Beaudouin <kiwi@oav.net> (xbeaudouin)
- Falk Stern <falk@fourecks.de> (fstern)
- Donovan Bridoux <donovan.bridoux@gmail.com> (PandaWawawa)
- Sebastian Neuner <sebastian@sneuner.org> (9er)
- Robert Zollner <wolfit_ro@yahoo.com> (Lupul)
- Richard Hartmann <richih@debian.org> (RichiH)
- Robert Gornall <roblnm@khobbits.co.uk> (KHobbits)
- Rob Gormley <robert@gormley.me> (rgormley)
- Richard Kojedzinszky <krichy@nmdps.net> (rkojedzinszky)
- Peter Lamperud <peter.lamperud@gmail.com> (vizay)
- Louis Bailleul <louis.bailleul@gmail.com> (alucardfh)
- Rick Hodger <rick@fuzzi.org.uk> (Tatermen)
- Eldon Koyle <ekoyle@gmail.com> (ekoyle)
- Jay McEntire <jay.mcentire@gmail.com> (jmacul2)
- Jonathan Bailey <jcbailey@code0.net> (jcbailey2)
- Ruairi Carroll <ruairi.carroll@gmail.com> (rucarrol)
- Maxim Tsyplakov <maxim.tsyplakov@gmail.com> (tsypa)
- D. Britz <github@wrind.de> (flatterlight)
- Tobias Herrmann <tobias@fiveninedigital.ch> (Mightea)
- Nicolas Guillaumin <nicolas+github@guillaumin.me> (nguillaumin)
- Jurrian van Iersel <jurrian@vaniersel.net> (jviersel)
- Adam Winberg <adam.winberg@gmail.com> (wiad)
- Maximilian Wilhelm <max@rfc2324.org> (BarbarossaTM)
- Jameson Finney <jameson.finney@gmail.com> (JamesonFinney)
- John Wells <john.wells@greatworx.com> (jbwiv)
- Henoc Khouilla <henoc.khouilla@gmail.com> (henocKA)
- Paul Blasquez <pblasquez@gmail.com> (pblasquez)
- Paul Heinrichs <pdheinrichs@gmail.com> (pheinrichs)
- Georges Dick <georges.dick@gmail.com> (GeorgesDick)
- Richard Lawley <richard@richardlawley.com> (richardlawley)
- Marco Di Cerbo <marco@dottoremoe.com> (marcodc)
- Ibrahim Tachijian <barhom@netsat.se> (barhom)
- Guillaume Coeugnet <aliasprotect-git@yahoo.fr> (gcoeugnet)
- Jared Newell <jared.newell@gmail.com> (Jaredn)
- Karsten Nerdinger <karsten-git-librenms@nerdinger.net> (piratonym)
- Michael Nguyen <mnguyen1289@gmail.com> (mnguyen1289)
- Casey Schoonover <casey.schoonover@llcc.edu> (cschoonover91)
- Chris A. Evans <thecityofguanyu@outlook.com> (thecityofguanyu)
- Rainer Schüler <github@layer3.de> (rschueler)
- Jussi Sorjonen <mieleton@mieleton.net> (mieleton)
- Jens Langhammer <jens@beryju.org> (BeryJu)
- Robert Verspuy <robert@exa.nl> (exarv)
- Peter Tkatchenko <peter@flytrace.com> (Peter2121)
- Marc Runkel <marc@runkel.org> (mrunkel)
- Josh Driver <keeperofdakeys@gmail.com> (keeperofdakeys)
- Felix Eckhofer <felix@eckhofer.com> (tribut)
- Vikram Adukia <adukia@dropbox.com> (justmedude)
- Tijmen de Mes <tijmen@ag-projects.com> (tijmenNL)
- Benjamin Busche <benjamin.busche@gmail.com> (optic00)
- Brandon Boudrias <bt.boudrias@gmail.com> (brandune)
- Andy Noyland <andrew@noyland.co.uk> (Zappatron)
- Ahmed Sajid <ahmed4343@hotmail.com> (ahmedsajid)
- Karsten Schmidt <git@guggemand.dk> (guggemand)
- Maxence POULAIN <maxence.poulain@eriador.info> (Linutux42)
- Florian Beer <fb@42dev.eu> (florianbeer)
- Vladislav Solovei <vladsol2009@gmail.com> (vladsol)
- Daniel van Dorp <daniel@vandorp.biz> (djvdorp)
- Phil Regnauld <regnauld@x0.dk> (reegnauld)
- Russell Morris <github@rkmorris.us> (arrmo)
- Bennett Blodinger <bennett.blodinger@gmail.com> (benwa)
- Michael Hansen <nerdalertdk@gmail.com> (nerdalertdk)
- Daniel Cox <danielcoxman@gmail.com> (ospfbgp)
- Joseph Cunningham <joey.was@gmail.com> (joeywas)
- Michael Van Delft <librenms@xo.tc> (HybridAU)
- Piotr Jurga <deutor1361@gmail.com> (deutor)
- Jonathon Koyle <jonathon.koyle@gmail.com> (jonathon-k)
- Tamas Szabo <jobs@szatam.com> (szatam)
- Dennis Væversted <dv@zitcom.dk> (dvaeversted)
- Morgan Henreaux <morgan@henreaux.com> (mhenreaux)
- Yves Boudreau <yves.boudreau@bgp.ca> (boudreau)
- Konrad Bechler <konrad@bechler.pl> (kbechler)
- Florent Bruchez <ftbz@me.com> (ftbz)
- Bartosz Radwan <b.radwan@citypartner.pl> (bartoszradwan)
- Kate Gerry <kate@fansubber.com> (kate66)
- Johan Zaxmy <johan@zaxmy.com> (Zaxmy)
- Ryan Gibbons <rtgibbons23@gmail.com> (rtgibbons)
- Layne Breitkreutz <github@thelenon.com> (Gorian)
- Karl Shea <karl@karlshea.com> (karlshea)
- Jason Ellison <infotek@gmail.com> (infotek)
- Justin Settle <jus10@partlycloudy.org> (jquagga)
- Alexander Kratzsch <klump@devrandom.se> (klump)
- Barry O'Donovan barry.odonovan@lightnet.ie (barryodonovan)
- Joseph Eames <j.eames@outlook.com> (j-ems)
- Eric Conroy <eric@conroy.co> (NetworkNub)
- Timothy Willey <developer@timothywilley.net> (twilley)
- Jon Ward	<librenms@yonzb.net> (yon2004)
- Ian Viemeister <github@ian.viemeister.com> (iviemeister)
- Thane Gill <me@thanegill.com> (thanegill)
- Christoffer Stokbæk <christoffers@easyspeedy.com> (stokbaek)
- Markus Wigge <markus@cultcom.de> (cultcom)
- Matthew Wall <llawwehttam@gmail.com> (llawwehttam)
- Andres Rahn <andreser@gmail.com> (Andreser)
- Philippe Mathieu-Daudé <philmd@users.noreply.github.com> (philmd)
- Christoph Zilian <czilian@hotmail.com> (czilian)
- Guillem Mateos <bbguillem@gmail.com> (guillemmateos)
- Joachim Tingvold <joachim@tingvold.com> (jallakim)
- Martin Zatloukal <slezi2@pvfree.net> (erotel)
- Matthew Schwen <mschwen@gmail.com> (mattschwen)
- Joel Cant <joel@linuxmod.co.uk> (NerdBlender)
- Aldemir Akpinar <aldemir.akpinar@gmail.com> (aldemira)
- Rob Nichols <rob@ignition360.com> (rdnn)
- Patrick Fruh <info@kaeltis.de> (Kaeltis)
- Julian Kornberger <jk+github@digineo.de> (corny)
- ant Kenworthy <git@manchetermonkey.co.uk> (mcrmonkey)
- Aleksandr Stankevic <aleksandr.stankevic@gmail.com> (sysmonk)
- Richard Mayhew <richard@splash.co.za> (InsaneSplash)
- Jacob <wackychocolatefactory@gmail.com> (wackychocolatefactory)
- Patrick Velder <patrick2+librenms@velder.li> (patrick7)
- Andrew Wippler <andrew.wippler+librenms@gmail.com> (andrewwippler)
- Robert Towster <rnt-github at towster.com> (towster)
- Rocky Luke <rockyluke@offline.net> (rockyluke)
- Tim Jackson <jackson.tim@gmail.com> (jackson-tim)
- Jørn-Stian Lønsetteig <jeg@glemte.no> (gilrim)
- Viktoria Rei Bauer <vbauer@stargazer.at> (ToeiRei)
- Ryan Eno <ryaneno@gmail.com> (VimCommando)
- Matt Peterson <matt@peterson.org> (dorkmatt)
- William George <wrgeorge1983@gmail.com> (wrgeorge1983)
- Valentin Parmeland <naoko.vp@gmail.com> (NK74)
- Michał Margula <michal@margula.pl> (alchemyx)
- Maclin Fuehr-Bush <macfuehrbush@gmail.com> (mobilemaclin)
- Robert Penziol <rpenziol@pdx.edu> (rpenziol)
- Stefan Behte <craig at haquarter.de> (craig)
- Zane C. Bowers-Hadley <vvelox@vvelox.net> (vvelox)
- Valentin Polonuyer <valik.vicious@gmail.com> (ValikVicious)
- Olivier Le Brouster <olb@nebkha.net> (ollb)
- Avery Payne <avery.p.payne@gmail.com> (apayne)
- Ryan Medlyn <ryan.medlyn@gmail.com> (rmedlyn)
- Mark Hughes <m@rkhugh.es> (markehme)
- Mark Abrahams <mark@abrahams.co.nz> (markabrahams)
- Klaas Tammling <klaas@tammling.hamburg> (KlaasT)
- Simon Mott <me@simonmott.co.uk> (tsumaru720)
- Hubert Ladet <mail4git38@gmail.com> (mail4git38)
- Deeps (deepseth)
- Jari Schäfer <jari.schaefer@gmail.com> (jarischaefer)
- Jan-Philipp Litza <janphilipp@litza.de> (jplitza)
- Chris Putnam <chrisputnam@gmail.com> (putnam)
- Jonathan Price <jonathan@jonathanprice.uk> (Pricetx)
- Remy de Boer <remy@slowpoke.nl> (remydb)
- Ben Klang <ben@alkaloid.net> (bklang)
- Tim Stallard <code@timstallard.me.uk> (TimStallard)
- Svenn D'Hert <admin at svennd.be> (svennd)
- Dominik Bay <db@rrbone.net> (eimann)
- Nick Peelman <nick@peelman.us> (peelman)
- Patrick Ryon <patrick@slashdoom.com> (slashdoom)
- Mike Williams <mike@mgww.net> (network-guy)
- Rob J. Epping <librenms@renf.us> (robje)
- Frank Petrilli <frank@petril.li> (frankpetrilli)
- Joel Kociolek <joel@kociolek.org> (lejoko)
- Rémy Jacquin <remy@remyj.fr> (remyj38)
- PipoCanaja <pipocanaja@gmail.com> [pipocanaja](https://github.com/pipocanaja/)

Observium was written by:
- Adam Armstrong
- Tom Laermans
- various others as indicated in the file contents and commit logs
